Module: Google::Apis::ApphubV1alpha

Defined in:
lib/google/apis/apphub_v1alpha.rb,
lib/google/apis/apphub_v1alpha/classes.rb,
lib/google/apis/apphub_v1alpha/service.rb,
lib/google/apis/apphub_v1alpha/gem_version.rb,
lib/google/apis/apphub_v1alpha/representations.rb

Overview

App Hub API

App Hub lets you build, operate, and manage applications on Google Cloud.

Defined Under Namespace

Classes: AppHubService, Application, Attributes, AuditConfig, AuditLogConfig, Binding, Boundary, CancelOperationRequest, Channel, ContactInfo, Criticality, DetachServiceProjectAttachmentRequest, DetachServiceProjectAttachmentResponse, DiscoveredService, DiscoveredWorkload, Empty, Environment, Expr, ExtendedMetadata, ExtendedMetadataSchema, FindUnregisteredServicesResponse, FindUnregisteredWorkloadsResponse, FunctionalType, Identity, ListApplicationsResponse, ListDiscoveredServicesResponse, ListDiscoveredWorkloadsResponse, ListExtendedMetadataSchemasResponse, ListLocationsResponse, ListOperationsResponse, ListServiceProjectAttachmentsResponse, ListServicesResponse, ListWorkloadsResponse, Location, LookupDiscoveredServiceResponse, LookupDiscoveredWorkloadResponse, LookupServiceProjectAttachmentResponse, Operation, OperationMetadata, Policy, RegistrationType, Scope, Service, ServiceProjectAttachment, ServiceProperties, ServiceReference, SetIamPolicyRequest, Status, TestIamPermissionsRequest, TestIamPermissionsResponse, Workload, WorkloadProperties, WorkloadReference

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-apphub_v1alpha gem

"0.18.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.19.0"
REVISION =

Revision of the discovery document this client was generated from

"20260520"
VERSION =

Version of the App Hub API this client connects to. This is NOT the gem version.

'V1alpha'
AUTH_CLOUD_PLATFORM =

See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.

'https://www.googleapis.com/auth/cloud-platform'