Class: Google::Apis::ApphubV1alpha::AppHubService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ApphubV1alpha::AppHubService
- Defined in:
- lib/google/apis/apphub_v1alpha/service.rb
Overview
App Hub API
App Hub lets you build, operate, and manage applications on Google Cloud.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://apphub.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_application(parent, application_object = nil, application_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Creates an Application in a host project and location.
-
#create_project_location_application_service(parent, service_object = nil, request_id: nil, service_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Creates a Service in an Application.
-
#create_project_location_application_workload(parent, workload_object = nil, request_id: nil, workload_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Creates a Workload in an Application.
-
#create_project_location_service_project_attachment(parent, service_project_attachment_object = nil, request_id: nil, service_project_attachment_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Attaches a service project to the host project.
-
#delete_project_location_application(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Deletes an Application in a host project and location.
-
#delete_project_location_application_service(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Deletes a Service from an Application.
-
#delete_project_location_application_workload(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Deletes a Workload from an Application.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Empty
Deletes a long-running operation.
-
#delete_project_location_service_project_attachment(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Deletes a service project attachment.
-
#detach_location_service_project_attachment(name, detach_service_project_attachment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::DetachServiceProjectAttachmentResponse
Detaches a service project from a host project.
-
#find_project_location_discovered_service_unregistered(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::FindUnregisteredServicesResponse
Finds unregistered services in a host project and location.
-
#find_project_location_discovered_workload_unregistered(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::FindUnregisteredWorkloadsResponse
Finds unregistered workloads in a host project and location.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Location
Gets information about a location.
-
#get_project_location_application(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Application
Gets an Application in a host project and location.
-
#get_project_location_application_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Policy
Gets the access control policy for a resource.
-
#get_project_location_application_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Service
Gets a Service in an Application.
-
#get_project_location_application_workload(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Workload
Gets a Workload in an Application.
-
#get_project_location_boundary(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Boundary
Gets a Boundary.
-
#get_project_location_discovered_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::DiscoveredService
Gets a Discovered Service in a host project and location.
-
#get_project_location_discovered_workload(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::DiscoveredWorkload
Gets a Discovered Workload in a host project and location.
-
#get_project_location_extended_metadata_schema(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ExtendedMetadataSchema
Gets an Extended Metadata Schema.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_service_project_attachment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ServiceProjectAttachment
Gets a service project attachment.
-
#initialize ⇒ AppHubService
constructor
A new instance of AppHubService.
-
#list_project_location_application_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListServicesResponse
Lists Services in an Application.
-
#list_project_location_application_workloads(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListWorkloadsResponse
Lists Workloads in an Application.
-
#list_project_location_applications(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListApplicationsResponse
Lists Applications in a host project and location.
-
#list_project_location_discovered_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListDiscoveredServicesResponse
Lists Discovered Services that can be added to an Application in a host project and location.
-
#list_project_location_discovered_workloads(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListDiscoveredWorkloadsResponse
Lists Discovered Workloads that can be added to an Application in a host project and location.
-
#list_project_location_extended_metadata_schemas(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListExtendedMetadataSchemasResponse
Lists Extended Metadata Schemas available in a host project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_service_project_attachments(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListServiceProjectAttachmentsResponse
Lists service projects attached to the host project.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListLocationsResponse
Lists information about the supported locations for this service.
-
#lookup_project_location_discovered_service(parent, uri: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::LookupDiscoveredServiceResponse
Lists a Discovered Service in a host project and location, with a given resource URI.
-
#lookup_project_location_discovered_workload(parent, uri: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::LookupDiscoveredWorkloadResponse
Lists a Discovered Workload in a host project and location, with a given resource URI.
-
#lookup_project_location_service_project_attachment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::LookupServiceProjectAttachmentResponse
Lists a service project attachment for a given service project.
-
#patch_project_location_application(name, application_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Updates an Application in a host project and location.
-
#patch_project_location_application_service(name, service_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Updates a Service in an Application.
-
#patch_project_location_application_workload(name, workload_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Updates a Workload in an Application.
-
#set_application_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Policy
Sets the access control policy on the specified resource.
-
#test_application_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#update_project_location_boundary(name, boundary_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Updates a Boundary.
Constructor Details
#initialize ⇒ AppHubService
Returns a new instance of AppHubService.
47 48 49 50 51 52 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-apphub_v1alpha', client_version: Google::Apis::ApphubV1alpha::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1509 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+name}:cancel', ) command.request_representation = Google::Apis::ApphubV1alpha::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::ApphubV1alpha::Empty::Representation command.response_class = Google::Apis::ApphubV1alpha::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_application(parent, application_object = nil, application_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Creates an Application in a host project and location.
331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 331 def create_project_location_application(parent, application_object = nil, application_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+parent}/applications', ) command.request_representation = Google::Apis::ApphubV1alpha::Application::Representation command.request_object = application_object command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['parent'] = parent unless parent.nil? command.query['applicationId'] = application_id unless application_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_application_service(parent, service_object = nil, request_id: nil, service_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Creates a Service in an Application.
677 678 679 680 681 682 683 684 685 686 687 688 689 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 677 def create_project_location_application_service(parent, service_object = nil, request_id: nil, service_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+parent}/services', ) command.request_representation = Google::Apis::ApphubV1alpha::Service::Representation command.request_object = service_object command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['serviceId'] = service_id unless service_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_application_workload(parent, workload_object = nil, request_id: nil, workload_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Creates a Workload in an Application.
905 906 907 908 909 910 911 912 913 914 915 916 917 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 905 def create_project_location_application_workload(parent, workload_object = nil, request_id: nil, workload_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+parent}/workloads', ) command.request_representation = Google::Apis::ApphubV1alpha::Workload::Representation command.request_object = workload_object command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['workloadId'] = workload_id unless workload_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_service_project_attachment(parent, service_project_attachment_object = nil, request_id: nil, service_project_attachment_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Attaches a service project to the host project.
1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1672 def (parent, = nil, request_id: nil, service_project_attachment_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+parent}/serviceProjectAttachments', ) command.request_representation = Google::Apis::ApphubV1alpha::ServiceProjectAttachment::Representation command.request_object = command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['serviceProjectAttachmentId'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_application(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Deletes an Application in a host project and location.
377 378 379 380 381 382 383 384 385 386 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 377 def delete_project_location_application(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_application_service(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Deletes a Service from an Application.
724 725 726 727 728 729 730 731 732 733 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 724 def delete_project_location_application_service(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_application_workload(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Deletes a Workload from an Application.
952 953 954 955 956 957 958 959 960 961 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 952 def delete_project_location_application_workload(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
1544 1545 1546 1547 1548 1549 1550 1551 1552 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1544 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Empty::Representation command.response_class = Google::Apis::ApphubV1alpha::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_service_project_attachment(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Deletes a service project attachment.
1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1719 def (name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#detach_location_service_project_attachment(name, detach_service_project_attachment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::DetachServiceProjectAttachmentResponse
Detaches a service project from a host project. You can call this API from any service project without needing access to the host project that it is attached to.
79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 79 def (name, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+name}:detachServiceProjectAttachment', ) command.request_representation = Google::Apis::ApphubV1alpha::DetachServiceProjectAttachmentRequest::Representation command.request_object = command.response_representation = Google::Apis::ApphubV1alpha::DetachServiceProjectAttachmentResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::DetachServiceProjectAttachmentResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#find_project_location_discovered_service_unregistered(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::FindUnregisteredServicesResponse
Finds unregistered services in a host project and location.
1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1126 def find_project_location_discovered_service_unregistered(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/discoveredServices:findUnregistered', ) command.response_representation = Google::Apis::ApphubV1alpha::FindUnregisteredServicesResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::FindUnregisteredServicesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#find_project_location_discovered_workload_unregistered(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::FindUnregisteredWorkloadsResponse
Finds unregistered workloads in a host project and location.
1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1283 def find_project_location_discovered_workload_unregistered(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/discoveredWorkloads:findUnregistered', ) command.response_representation = Google::Apis::ApphubV1alpha::FindUnregisteredWorkloadsResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::FindUnregisteredWorkloadsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Location
Gets information about a location.
111 112 113 114 115 116 117 118 119 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 111 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Location::Representation command.response_class = Google::Apis::ApphubV1alpha::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_application(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Application
Gets an Application in a host project and location.
409 410 411 412 413 414 415 416 417 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 409 def get_project_location_application(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Application::Representation command.response_class = Google::Apis::ApphubV1alpha::Application command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_application_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
453 454 455 456 457 458 459 460 461 462 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 453 def get_project_location_application_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::ApphubV1alpha::Policy::Representation command.response_class = Google::Apis::ApphubV1alpha::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_application_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Service
Gets a Service in an Application.
757 758 759 760 761 762 763 764 765 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 757 def get_project_location_application_service(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Service::Representation command.response_class = Google::Apis::ApphubV1alpha::Service command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_application_workload(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Workload
Gets a Workload in an Application.
985 986 987 988 989 990 991 992 993 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 985 def get_project_location_application_workload(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Workload::Representation command.response_class = Google::Apis::ApphubV1alpha::Workload command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_boundary(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Boundary
Gets a Boundary.
142 143 144 145 146 147 148 149 150 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 142 def get_project_location_boundary(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Boundary::Representation command.response_class = Google::Apis::ApphubV1alpha::Boundary command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_discovered_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::DiscoveredService
Gets a Discovered Service in a host project and location.
1162 1163 1164 1165 1166 1167 1168 1169 1170 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1162 def get_project_location_discovered_service(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::DiscoveredService::Representation command.response_class = Google::Apis::ApphubV1alpha::DiscoveredService command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_discovered_workload(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::DiscoveredWorkload
Gets a Discovered Workload in a host project and location.
1319 1320 1321 1322 1323 1324 1325 1326 1327 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1319 def get_project_location_discovered_workload(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::DiscoveredWorkload::Representation command.response_class = Google::Apis::ApphubV1alpha::DiscoveredWorkload command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_extended_metadata_schema(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ExtendedMetadataSchema
Gets an Extended Metadata Schema.
1433 1434 1435 1436 1437 1438 1439 1440 1441 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1433 def (name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::ExtendedMetadataSchema::Representation command.response_class = Google::Apis::ApphubV1alpha::ExtendedMetadataSchema command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1575 1576 1577 1578 1579 1580 1581 1582 1583 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1575 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_service_project_attachment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ServiceProjectAttachment
Gets a service project attachment.
1752 1753 1754 1755 1756 1757 1758 1759 1760 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1752 def (name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::ServiceProjectAttachment::Representation command.response_class = Google::Apis::ApphubV1alpha::ServiceProjectAttachment command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_application_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListServicesResponse
Lists Services in an Application.
798 799 800 801 802 803 804 805 806 807 808 809 810 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 798 def list_project_location_application_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/services', ) command.response_representation = Google::Apis::ApphubV1alpha::ListServicesResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::ListServicesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_application_workloads(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListWorkloadsResponse
Lists Workloads in an Application.
1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1026 def list_project_location_application_workloads(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/workloads', ) command.response_representation = Google::Apis::ApphubV1alpha::ListWorkloadsResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::ListWorkloadsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_applications(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListApplicationsResponse
Lists Applications in a host project and location.
494 495 496 497 498 499 500 501 502 503 504 505 506 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 494 def list_project_location_applications(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/applications', ) command.response_representation = Google::Apis::ApphubV1alpha::ListApplicationsResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::ListApplicationsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_discovered_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListDiscoveredServicesResponse
Lists Discovered Services that can be added to an Application in a host project and location.
1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1203 def list_project_location_discovered_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/discoveredServices', ) command.response_representation = Google::Apis::ApphubV1alpha::ListDiscoveredServicesResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::ListDiscoveredServicesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_discovered_workloads(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListDiscoveredWorkloadsResponse
Lists Discovered Workloads that can be added to an Application in a host project and location.
1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1360 def list_project_location_discovered_workloads(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/discoveredWorkloads', ) command.response_representation = Google::Apis::ApphubV1alpha::ListDiscoveredWorkloadsResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::ListDiscoveredWorkloadsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_extended_metadata_schemas(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListExtendedMetadataSchemasResponse
Lists Extended Metadata Schemas available in a host project and location.
1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1469 def (parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/extendedMetadataSchemas', ) command.response_representation = Google::Apis::ApphubV1alpha::ListExtendedMetadataSchemasResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::ListExtendedMetadataSchemasResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1620 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}/operations', ) command.response_representation = Google::Apis::ApphubV1alpha::ListOperationsResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_service_project_attachments(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListServiceProjectAttachmentsResponse
Lists service projects attached to the host project.
1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1793 def (parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/serviceProjectAttachments', ) command.response_representation = Google::Apis::ApphubV1alpha::ListServiceProjectAttachmentsResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::ListServiceProjectAttachmentsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the
ListLocationsRequest.name field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 194 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}/locations', ) command.response_representation = Google::Apis::ApphubV1alpha::ListLocationsResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#lookup_project_location_discovered_service(parent, uri: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::LookupDiscoveredServiceResponse
Lists a Discovered Service in a host project and location, with a given resource URI.
1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1242 def lookup_project_location_discovered_service(parent, uri: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/discoveredServices:lookup', ) command.response_representation = Google::Apis::ApphubV1alpha::LookupDiscoveredServiceResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::LookupDiscoveredServiceResponse command.params['parent'] = parent unless parent.nil? command.query['uri'] = uri unless uri.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#lookup_project_location_discovered_workload(parent, uri: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::LookupDiscoveredWorkloadResponse
Lists a Discovered Workload in a host project and location, with a given resource URI.
1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1399 def lookup_project_location_discovered_workload(parent, uri: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/discoveredWorkloads:lookup', ) command.response_representation = Google::Apis::ApphubV1alpha::LookupDiscoveredWorkloadResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::LookupDiscoveredWorkloadResponse command.params['parent'] = parent unless parent.nil? command.query['uri'] = uri unless uri.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#lookup_project_location_service_project_attachment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::LookupServiceProjectAttachmentResponse
Lists a service project attachment for a given service project. You can call this API from any project to find if it is attached to a host project.
231 232 233 234 235 236 237 238 239 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 231 def (name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}:lookupServiceProjectAttachment', ) command.response_representation = Google::Apis::ApphubV1alpha::LookupServiceProjectAttachmentResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::LookupServiceProjectAttachmentResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_application(name, application_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Updates an Application in a host project and location.
549 550 551 552 553 554 555 556 557 558 559 560 561 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 549 def patch_project_location_application(name, application_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/{+name}', ) command.request_representation = Google::Apis::ApphubV1alpha::Application::Representation command.request_object = application_object command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_application_service(name, service_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Updates a Service in an Application.
853 854 855 856 857 858 859 860 861 862 863 864 865 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 853 def patch_project_location_application_service(name, service_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/{+name}', ) command.request_representation = Google::Apis::ApphubV1alpha::Service::Representation command.request_object = service_object command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_application_workload(name, workload_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Updates a Workload in an Application.
1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1082 def patch_project_location_application_workload(name, workload_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/{+name}', ) command.request_representation = Google::Apis::ApphubV1alpha::Workload::Representation command.request_object = workload_object command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_application_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
588 589 590 591 592 593 594 595 596 597 598 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 588 def set_application_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ApphubV1alpha::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::ApphubV1alpha::Policy::Representation command.response_class = Google::Apis::ApphubV1alpha::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_application_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
627 628 629 630 631 632 633 634 635 636 637 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 627 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ApphubV1alpha::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ApphubV1alpha::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_project_location_boundary(name, boundary_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Updates a Boundary.
280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 280 def update_project_location_boundary(name, boundary_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/{+name}', ) command.request_representation = Google::Apis::ApphubV1alpha::Boundary::Representation command.request_object = boundary_object command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |