Class: Google::Apis::ApphubV1alpha::DiscoveredWorkload

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apphub_v1alpha/classes.rb,
lib/google/apis/apphub_v1alpha/representations.rb,
lib/google/apis/apphub_v1alpha/representations.rb

Overview

DiscoveredWorkload is a binary deployment (such as managed instance groups ( MIGs) and GKE deployments) that performs the smallest logical subset of business functionality. A discovered workload can be registered to an App Hub Workload.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoveredWorkload

Returns a new instance of DiscoveredWorkload.



539
540
541
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 539

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Identifier. The resource name of the discovered workload. Format: "projects/ host-project-id/locations/location/discoveredWorkloads/uuid" Corresponds to the JSON property name

Returns:

  • (String)


527
528
529
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 527

def name
  @name
end

#workload_propertiesGoogle::Apis::ApphubV1alpha::WorkloadProperties

Properties of an underlying compute resource represented by the Workload. Corresponds to the JSON property workloadProperties



532
533
534
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 532

def workload_properties
  @workload_properties
end

#workload_referenceGoogle::Apis::ApphubV1alpha::WorkloadReference

Reference of an underlying compute resource represented by the Workload. Corresponds to the JSON property workloadReference



537
538
539
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 537

def workload_reference
  @workload_reference
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



544
545
546
547
548
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 544

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @workload_properties = args[:workload_properties] if args.key?(:workload_properties)
  @workload_reference = args[:workload_reference] if args.key?(:workload_reference)
end