Class: Google::Apis::ApphubV1alpha::ListServiceProjectAttachmentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ApphubV1alpha::ListServiceProjectAttachmentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apphub_v1alpha/classes.rb,
lib/google/apis/apphub_v1alpha/representations.rb,
lib/google/apis/apphub_v1alpha/representations.rb
Overview
Response for ListServiceProjectAttachments.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#service_project_attachments ⇒ Array<Google::Apis::ApphubV1alpha::ServiceProjectAttachment>
List of service project attachments.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListServiceProjectAttachmentsResponse
constructor
A new instance of ListServiceProjectAttachmentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListServiceProjectAttachmentsResponse
Returns a new instance of ListServiceProjectAttachmentsResponse.
1000 1001 1002 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1000 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
988 989 990 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 988 def next_page_token @next_page_token end |
#service_project_attachments ⇒ Array<Google::Apis::ApphubV1alpha::ServiceProjectAttachment>
List of service project attachments.
Corresponds to the JSON property serviceProjectAttachments
993 994 995 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 993 def @service_project_attachments end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
998 999 1000 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 998 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1005 1006 1007 1008 1009 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1005 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @service_project_attachments = args[:service_project_attachments] if args.key?(:service_project_attachments) @unreachable = args[:unreachable] if args.key?(:unreachable) end |