Class: Google::Apis::ApphubV1alpha::LookupDiscoveredServiceResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apphub_v1alpha/classes.rb,
lib/google/apis/apphub_v1alpha/representations.rb,
lib/google/apis/apphub_v1alpha/representations.rb

Overview

Response for LookupDiscoveredService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LookupDiscoveredServiceResponse

Returns a new instance of LookupDiscoveredServiceResponse.



986
987
988
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 986

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#discovered_serviceGoogle::Apis::ApphubV1alpha::DiscoveredService

DiscoveredService is a network or API interface that exposes some functionality to clients for consumption over the network. A discovered service can be registered to a App Hub service. Corresponds to the JSON property discoveredService



984
985
986
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 984

def discovered_service
  @discovered_service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



991
992
993
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 991

def update!(**args)
  @discovered_service = args[:discovered_service] if args.key?(:discovered_service)
end