Class: Google::Apis::ApphubV1alpha::Service
- Inherits:
-
Object
- Object
- Google::Apis::ApphubV1alpha::Service
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apphub_v1alpha/classes.rb,
lib/google/apis/apphub_v1alpha/representations.rb,
lib/google/apis/apphub_v1alpha/representations.rb
Overview
Service is an App Hub data model that contains a discovered service, which represents a network or API interface that exposes some functionality to clients for consumption over the network.
Instance Attribute Summary collapse
-
#attributes ⇒ Google::Apis::ApphubV1alpha::Attributes
Consumer provided attributes.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#discovered_service ⇒ String
Required.
-
#display_name ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#service_properties ⇒ Google::Apis::ApphubV1alpha::ServiceProperties
Properties of an underlying cloud resource that can comprise a Service.
-
#service_reference ⇒ Google::Apis::ApphubV1alpha::ServiceReference
Reference to an underlying networking resource that can comprise a Service.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Service
constructor
A new instance of Service.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Service
Returns a new instance of Service.
1506 1507 1508 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1506 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Google::Apis::ApphubV1alpha::Attributes
Consumer provided attributes.
Corresponds to the JSON property attributes
1450 1451 1452 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1450 def attributes @attributes end |
#create_time ⇒ String
Output only. Create time.
Corresponds to the JSON property createTime
1455 1456 1457 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1455 def create_time @create_time end |
#description ⇒ String
Optional. User-defined description of a Service. Can have a maximum length of
2048 characters.
Corresponds to the JSON property description
1461 1462 1463 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1461 def description @description end |
#discovered_service ⇒ String
Required. Immutable. The resource name of the original discovered service.
Corresponds to the JSON property discoveredService
1466 1467 1468 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1466 def discovered_service @discovered_service end |
#display_name ⇒ String
Optional. User-defined name for the Service. Can have a maximum length of 63
characters.
Corresponds to the JSON property displayName
1472 1473 1474 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1472 def display_name @display_name end |
#name ⇒ String
Identifier. The resource name of a Service. Format: "projects/host-project-
id/locations/location/applications/application-id/services/service-id"
Corresponds to the JSON property name
1478 1479 1480 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1478 def name @name end |
#service_properties ⇒ Google::Apis::ApphubV1alpha::ServiceProperties
Properties of an underlying cloud resource that can comprise a Service.
Corresponds to the JSON property serviceProperties
1483 1484 1485 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1483 def service_properties @service_properties end |
#service_reference ⇒ Google::Apis::ApphubV1alpha::ServiceReference
Reference to an underlying networking resource that can comprise a Service.
Corresponds to the JSON property serviceReference
1488 1489 1490 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1488 def service_reference @service_reference end |
#state ⇒ String
Output only. Service state.
Corresponds to the JSON property state
1493 1494 1495 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1493 def state @state end |
#uid ⇒ String
Output only. A universally unique identifier (UUID) for the Service in the
UUID4 format.
Corresponds to the JSON property uid
1499 1500 1501 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1499 def uid @uid end |
#update_time ⇒ String
Output only. Update time.
Corresponds to the JSON property updateTime
1504 1505 1506 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1504 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1511 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @discovered_service = args[:discovered_service] if args.key?(:discovered_service) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @service_properties = args[:service_properties] if args.key?(:service_properties) @service_reference = args[:service_reference] if args.key?(:service_reference) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |