Class: Google::Apis::ApphubV1alpha::ServiceProjectAttachment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apphub_v1alpha/classes.rb,
lib/google/apis/apphub_v1alpha/representations.rb,
lib/google/apis/apphub_v1alpha/representations.rb

Overview

ServiceProjectAttachment represents an attachment from a service project to a host project. Service projects contain the underlying cloud infrastructure resources, and expose these resources to the host project through a ServiceProjectAttachment. With the attachments, the host project can provide an aggregated view of resources across all service projects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceProjectAttachment

Returns a new instance of ServiceProjectAttachment.



1564
1565
1566
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1564

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Create time. Corresponds to the JSON property createTime

Returns:

  • (String)


1537
1538
1539
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1537

def create_time
  @create_time
end

#nameString

Identifier. The resource name of a ServiceProjectAttachment. Format: " projects/host-project-id/locations/global/serviceProjectAttachments/service- project-id." Corresponds to the JSON property name

Returns:

  • (String)


1544
1545
1546
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1544

def name
  @name
end

#service_projectString

Required. Immutable. Service project name in the format: "projects/abc" or " projects/123". As input, project name with either project id or number are accepted. As output, this field will contain project number. Corresponds to the JSON property serviceProject

Returns:

  • (String)


1551
1552
1553
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1551

def service_project
  @service_project
end

#stateString

Output only. ServiceProjectAttachment state. Corresponds to the JSON property state

Returns:

  • (String)


1556
1557
1558
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1556

def state
  @state
end

#uidString

Output only. A globally unique identifier (in UUID4 format) for the ServiceProjectAttachment. Corresponds to the JSON property uid

Returns:

  • (String)


1562
1563
1564
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1562

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1569
1570
1571
1572
1573
1574
1575
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1569

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @service_project = args[:service_project] if args.key?(:service_project)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
end