Class: Google::Apis::ApphubV1alpha::ServiceProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apphub_v1alpha/classes.rb,
lib/google/apis/apphub_v1alpha/representations.rb,
lib/google/apis/apphub_v1alpha/representations.rb

Overview

Properties of an underlying cloud resource that can comprise a Service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceProperties

Returns a new instance of ServiceProperties.



1623
1624
1625
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1623

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#extended_metadataHash<String,Google::Apis::ApphubV1alpha::ExtendedMetadata>

Output only. Additional metadata specific to the resource type. The key is a string that identifies the type of metadata and the value is the metadata contents specific to that type. Key format: apphub.googleapis.com/ metadataType` Corresponds to the JSON propertyextendedMetadata`



1588
1589
1590
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1588

def 
  @extended_metadata
end

#functional_typeGoogle::Apis::ApphubV1alpha::FunctionalType

The functional type of a service or workload. Corresponds to the JSON property functionalType



1593
1594
1595
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1593

def functional_type
  @functional_type
end

#gcp_projectString

Output only. The service project identifier that the underlying cloud resource resides in. Corresponds to the JSON property gcpProject

Returns:

  • (String)


1599
1600
1601
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1599

def gcp_project
  @gcp_project
end

#identityGoogle::Apis::ApphubV1alpha::Identity

The identity associated with a service or workload. Corresponds to the JSON property identity



1604
1605
1606
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1604

def identity
  @identity
end

#locationString

Output only. The location that the underlying resource resides in, for example, us-west1. Corresponds to the JSON property location

Returns:

  • (String)


1610
1611
1612
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1610

def location
  @location
end

#registration_typeGoogle::Apis::ApphubV1alpha::RegistrationType

The registration type of a service. Corresponds to the JSON property registrationType



1615
1616
1617
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1615

def registration_type
  @registration_type
end

#zoneString

Output only. The location that the underlying resource resides in if it is zonal, for example, us-west1-a). Corresponds to the JSON property zone

Returns:

  • (String)


1621
1622
1623
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1621

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1628
1629
1630
1631
1632
1633
1634
1635
1636
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1628

def update!(**args)
  @extended_metadata = args[:extended_metadata] if args.key?(:extended_metadata)
  @functional_type = args[:functional_type] if args.key?(:functional_type)
  @gcp_project = args[:gcp_project] if args.key?(:gcp_project)
  @identity = args[:identity] if args.key?(:identity)
  @location = args[:location] if args.key?(:location)
  @registration_type = args[:registration_type] if args.key?(:registration_type)
  @zone = args[:zone] if args.key?(:zone)
end