Class: Google::Apis::ApphubV1alpha::Workload
- Inherits:
-
Object
- Object
- Google::Apis::ApphubV1alpha::Workload
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apphub_v1alpha/classes.rb,
lib/google/apis/apphub_v1alpha/representations.rb,
lib/google/apis/apphub_v1alpha/representations.rb
Overview
Workload is an App Hub data model that contains a discovered workload, which represents a binary deployment (such as managed instance groups (MIGs) and GKE deployments) that performs the smallest logical subset of business functionality.
Instance Attribute Summary collapse
-
#attributes ⇒ Google::Apis::ApphubV1alpha::Attributes
Consumer provided attributes.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#discovered_workload ⇒ String
Required.
-
#display_name ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#workload_properties ⇒ Google::Apis::ApphubV1alpha::WorkloadProperties
Properties of an underlying compute resource represented by the Workload.
-
#workload_reference ⇒ Google::Apis::ApphubV1alpha::WorkloadReference
Reference of an underlying compute resource represented by the Workload.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Workload
constructor
A new instance of Workload.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Workload
Returns a new instance of Workload.
1866 1867 1868 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1866 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Google::Apis::ApphubV1alpha::Attributes
Consumer provided attributes.
Corresponds to the JSON property attributes
1809 1810 1811 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1809 def attributes @attributes end |
#create_time ⇒ String
Output only. Create time.
Corresponds to the JSON property createTime
1814 1815 1816 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1814 def create_time @create_time end |
#description ⇒ String
Optional. User-defined description of a Workload. Can have a maximum length of
2048 characters.
Corresponds to the JSON property description
1820 1821 1822 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1820 def description @description end |
#discovered_workload ⇒ String
Required. Immutable. The resource name of the original discovered workload.
Corresponds to the JSON property discoveredWorkload
1825 1826 1827 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1825 def discovered_workload @discovered_workload end |
#display_name ⇒ String
Optional. User-defined name for the Workload. Can have a maximum length of 63
characters.
Corresponds to the JSON property displayName
1831 1832 1833 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1831 def display_name @display_name end |
#name ⇒ String
Identifier. The resource name of the Workload. Format: "projects/host-
project-id/locations/location/applications/application-id/workloads/
workload-id"
Corresponds to the JSON property name
1838 1839 1840 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1838 def name @name end |
#state ⇒ String
Output only. Workload state.
Corresponds to the JSON property state
1843 1844 1845 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1843 def state @state end |
#uid ⇒ String
Output only. A universally unique identifier (UUID) for the Workload in the
UUID4 format.
Corresponds to the JSON property uid
1849 1850 1851 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1849 def uid @uid end |
#update_time ⇒ String
Output only. Update time.
Corresponds to the JSON property updateTime
1854 1855 1856 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1854 def update_time @update_time end |
#workload_properties ⇒ Google::Apis::ApphubV1alpha::WorkloadProperties
Properties of an underlying compute resource represented by the Workload.
Corresponds to the JSON property workloadProperties
1859 1860 1861 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1859 def workload_properties @workload_properties end |
#workload_reference ⇒ Google::Apis::ApphubV1alpha::WorkloadReference
Reference of an underlying compute resource represented by the Workload.
Corresponds to the JSON property workloadReference
1864 1865 1866 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1864 def workload_reference @workload_reference end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1871 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @discovered_workload = args[:discovered_workload] if args.key?(:discovered_workload) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @workload_properties = args[:workload_properties] if args.key?(:workload_properties) @workload_reference = args[:workload_reference] if args.key?(:workload_reference) end |