Class: Google::Apis::ApphubV1alpha::AppHubService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ApphubV1alpha::AppHubService
- Defined in:
- lib/google/apis/apphub_v1alpha/service.rb
Overview
App Hub API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://apphub.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_application(parent, application_object = nil, application_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Creates an Application in a host project and location.
-
#create_project_location_application_service(parent, service_object = nil, request_id: nil, service_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Creates a Service in an Application.
-
#create_project_location_application_workload(parent, workload_object = nil, request_id: nil, workload_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Creates a Workload in an Application.
-
#create_project_location_service_project_attachment(parent, service_project_attachment_object = nil, request_id: nil, service_project_attachment_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Attaches a service project to the host project.
-
#delete_project_location_application(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Deletes an Application in a host project and location.
-
#delete_project_location_application_service(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Deletes a Service from an Application.
-
#delete_project_location_application_workload(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Deletes a Workload from an Application.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Empty
Deletes a long-running operation.
-
#delete_project_location_service_project_attachment(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Deletes a service project attachment.
-
#detach_location_service_project_attachment(name, detach_service_project_attachment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::DetachServiceProjectAttachmentResponse
Detaches a service project from a host project.
-
#find_project_location_discovered_service_unregistered(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::FindUnregisteredServicesResponse
Finds unregistered services in a host project and location.
-
#find_project_location_discovered_workload_unregistered(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::FindUnregisteredWorkloadsResponse
Finds unregistered workloads in a host project and location.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Location
Gets information about a location.
-
#get_project_location_application(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Application
Gets an Application in a host project and location.
-
#get_project_location_application_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Policy
Gets the access control policy for a resource.
-
#get_project_location_application_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Service
Gets a Service in an Application.
-
#get_project_location_application_workload(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Workload
Gets a Workload in an Application.
-
#get_project_location_discovered_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::DiscoveredService
Gets a Discovered Service in a host project and location.
-
#get_project_location_discovered_workload(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::DiscoveredWorkload
Gets a Discovered Workload in a host project and location.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_service_project_attachment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ServiceProjectAttachment
Gets a service project attachment.
-
#initialize ⇒ AppHubService
constructor
A new instance of AppHubService.
-
#list_project_location_application_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListServicesResponse
Lists Services in an Application.
-
#list_project_location_application_workloads(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListWorkloadsResponse
Lists Workloads in an Application.
-
#list_project_location_applications(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListApplicationsResponse
Lists Applications in a host project and location.
-
#list_project_location_discovered_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListDiscoveredServicesResponse
Lists Discovered Services that can be added to an Application in a host project and location.
-
#list_project_location_discovered_workloads(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListDiscoveredWorkloadsResponse
Lists Discovered Workloads that can be added to an Application in a host project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_service_project_attachments(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListServiceProjectAttachmentsResponse
Lists service projects attached to the host project.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListLocationsResponse
Lists information about the supported locations for this service.
-
#lookup_project_location_discovered_service(parent, uri: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::LookupDiscoveredServiceResponse
Lists a Discovered Service in a host project and location, with a given resource URI.
-
#lookup_project_location_discovered_workload(parent, uri: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::LookupDiscoveredWorkloadResponse
Lists a Discovered Workload in a host project and location, with a given resource URI.
-
#lookup_project_location_service_project_attachment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::LookupServiceProjectAttachmentResponse
Lists a service project attachment for a given service project.
-
#patch_project_location_application(name, application_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Updates an Application in a host project and location.
-
#patch_project_location_application_service(name, service_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Updates a Service in an Application.
-
#patch_project_location_application_workload(name, workload_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Updates a Workload in an Application.
-
#set_application_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Policy
Sets the access control policy on the specified resource.
-
#test_application_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
Constructor Details
#initialize ⇒ AppHubService
Returns a new instance of AppHubService.
47 48 49 50 51 52 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-apphub_v1alpha', client_version: Google::Apis::ApphubV1alpha::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1345 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+name}:cancel', ) command.request_representation = Google::Apis::ApphubV1alpha::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::ApphubV1alpha::Empty::Representation command.response_class = Google::Apis::ApphubV1alpha::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_application(parent, application_object = nil, application_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Creates an Application in a host project and location.
238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 238 def create_project_location_application(parent, application_object = nil, application_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+parent}/applications', ) command.request_representation = Google::Apis::ApphubV1alpha::Application::Representation command.request_object = application_object command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['parent'] = parent unless parent.nil? command.query['applicationId'] = application_id unless application_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_application_service(parent, service_object = nil, request_id: nil, service_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Creates a Service in an Application.
584 585 586 587 588 589 590 591 592 593 594 595 596 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 584 def create_project_location_application_service(parent, service_object = nil, request_id: nil, service_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+parent}/services', ) command.request_representation = Google::Apis::ApphubV1alpha::Service::Representation command.request_object = service_object command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['serviceId'] = service_id unless service_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_application_workload(parent, workload_object = nil, request_id: nil, workload_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Creates a Workload in an Application.
812 813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 812 def create_project_location_application_workload(parent, workload_object = nil, request_id: nil, workload_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+parent}/workloads', ) command.request_representation = Google::Apis::ApphubV1alpha::Workload::Representation command.request_object = workload_object command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['workloadId'] = workload_id unless workload_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_service_project_attachment(parent, service_project_attachment_object = nil, request_id: nil, service_project_attachment_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Attaches a service project to the host project.
1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1507 def (parent, = nil, request_id: nil, service_project_attachment_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+parent}/serviceProjectAttachments', ) command.request_representation = Google::Apis::ApphubV1alpha::ServiceProjectAttachment::Representation command.request_object = command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['serviceProjectAttachmentId'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_application(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Deletes an Application in a host project and location.
284 285 286 287 288 289 290 291 292 293 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 284 def delete_project_location_application(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_application_service(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Deletes a Service from an Application.
631 632 633 634 635 636 637 638 639 640 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 631 def delete_project_location_application_service(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_application_workload(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Deletes a Workload from an Application.
859 860 861 862 863 864 865 866 867 868 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 859 def delete_project_location_application_workload(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
1380 1381 1382 1383 1384 1385 1386 1387 1388 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1380 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Empty::Representation command.response_class = Google::Apis::ApphubV1alpha::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_service_project_attachment(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Deletes a service project attachment.
1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1554 def (name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#detach_location_service_project_attachment(name, detach_service_project_attachment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::DetachServiceProjectAttachmentResponse
Detaches a service project from a host project. You can call this API from any service project without needing access to the host project that it is attached to.
79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 79 def (name, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+name}:detachServiceProjectAttachment', ) command.request_representation = Google::Apis::ApphubV1alpha::DetachServiceProjectAttachmentRequest::Representation command.request_object = command.response_representation = Google::Apis::ApphubV1alpha::DetachServiceProjectAttachmentResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::DetachServiceProjectAttachmentResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#find_project_location_discovered_service_unregistered(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::FindUnregisteredServicesResponse
Finds unregistered services in a host project and location.
1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1033 def find_project_location_discovered_service_unregistered(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/discoveredServices:findUnregistered', ) command.response_representation = Google::Apis::ApphubV1alpha::FindUnregisteredServicesResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::FindUnregisteredServicesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#find_project_location_discovered_workload_unregistered(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::FindUnregisteredWorkloadsResponse
Finds unregistered workloads in a host project and location.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1190 def find_project_location_discovered_workload_unregistered(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/discoveredWorkloads:findUnregistered', ) command.response_representation = Google::Apis::ApphubV1alpha::FindUnregisteredWorkloadsResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::FindUnregisteredWorkloadsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Location
Gets information about a location.
111 112 113 114 115 116 117 118 119 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 111 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Location::Representation command.response_class = Google::Apis::ApphubV1alpha::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_application(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Application
Gets an Application in a host project and location.
316 317 318 319 320 321 322 323 324 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 316 def get_project_location_application(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Application::Representation command.response_class = Google::Apis::ApphubV1alpha::Application command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_application_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
360 361 362 363 364 365 366 367 368 369 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 360 def get_project_location_application_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::ApphubV1alpha::Policy::Representation command.response_class = Google::Apis::ApphubV1alpha::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_application_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Service
Gets a Service in an Application.
664 665 666 667 668 669 670 671 672 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 664 def get_project_location_application_service(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Service::Representation command.response_class = Google::Apis::ApphubV1alpha::Service command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_application_workload(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Workload
Gets a Workload in an Application.
892 893 894 895 896 897 898 899 900 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 892 def get_project_location_application_workload(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Workload::Representation command.response_class = Google::Apis::ApphubV1alpha::Workload command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_discovered_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::DiscoveredService
Gets a Discovered Service in a host project and location.
1069 1070 1071 1072 1073 1074 1075 1076 1077 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1069 def get_project_location_discovered_service(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::DiscoveredService::Representation command.response_class = Google::Apis::ApphubV1alpha::DiscoveredService command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_discovered_workload(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::DiscoveredWorkload
Gets a Discovered Workload in a host project and location.
1226 1227 1228 1229 1230 1231 1232 1233 1234 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1226 def get_project_location_discovered_workload(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::DiscoveredWorkload::Representation command.response_class = Google::Apis::ApphubV1alpha::DiscoveredWorkload command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1411 1412 1413 1414 1415 1416 1417 1418 1419 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1411 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_service_project_attachment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ServiceProjectAttachment
Gets a service project attachment.
1587 1588 1589 1590 1591 1592 1593 1594 1595 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1587 def (name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::ApphubV1alpha::ServiceProjectAttachment::Representation command.response_class = Google::Apis::ApphubV1alpha::ServiceProjectAttachment command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_application_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListServicesResponse
Lists Services in an Application.
705 706 707 708 709 710 711 712 713 714 715 716 717 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 705 def list_project_location_application_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/services', ) command.response_representation = Google::Apis::ApphubV1alpha::ListServicesResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::ListServicesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_application_workloads(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListWorkloadsResponse
Lists Workloads in an Application.
933 934 935 936 937 938 939 940 941 942 943 944 945 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 933 def list_project_location_application_workloads(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/workloads', ) command.response_representation = Google::Apis::ApphubV1alpha::ListWorkloadsResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::ListWorkloadsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_applications(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListApplicationsResponse
Lists Applications in a host project and location.
401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 401 def list_project_location_applications(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/applications', ) command.response_representation = Google::Apis::ApphubV1alpha::ListApplicationsResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::ListApplicationsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_discovered_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListDiscoveredServicesResponse
Lists Discovered Services that can be added to an Application in a host project and location.
1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1110 def list_project_location_discovered_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/discoveredServices', ) command.response_representation = Google::Apis::ApphubV1alpha::ListDiscoveredServicesResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::ListDiscoveredServicesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_discovered_workloads(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListDiscoveredWorkloadsResponse
Lists Discovered Workloads that can be added to an Application in a host project and location.
1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1267 def list_project_location_discovered_workloads(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/discoveredWorkloads', ) command.response_representation = Google::Apis::ApphubV1alpha::ListDiscoveredWorkloadsResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::ListDiscoveredWorkloadsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1455 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}/operations', ) command.response_representation = Google::Apis::ApphubV1alpha::ListOperationsResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_service_project_attachments(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListServiceProjectAttachmentsResponse
Lists service projects attached to the host project.
1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1628 def (parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/serviceProjectAttachments', ) command.response_representation = Google::Apis::ApphubV1alpha::ListServiceProjectAttachmentsResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::ListServiceProjectAttachmentsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::ListLocationsResponse
Lists information about the supported locations for this service.
154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 154 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}/locations', ) command.response_representation = Google::Apis::ApphubV1alpha::ListLocationsResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#lookup_project_location_discovered_service(parent, uri: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::LookupDiscoveredServiceResponse
Lists a Discovered Service in a host project and location, with a given resource URI.
1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1149 def lookup_project_location_discovered_service(parent, uri: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/discoveredServices:lookup', ) command.response_representation = Google::Apis::ApphubV1alpha::LookupDiscoveredServiceResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::LookupDiscoveredServiceResponse command.params['parent'] = parent unless parent.nil? command.query['uri'] = uri unless uri.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#lookup_project_location_discovered_workload(parent, uri: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::LookupDiscoveredWorkloadResponse
Lists a Discovered Workload in a host project and location, with a given resource URI.
1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 1306 def lookup_project_location_discovered_workload(parent, uri: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/discoveredWorkloads:lookup', ) command.response_representation = Google::Apis::ApphubV1alpha::LookupDiscoveredWorkloadResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::LookupDiscoveredWorkloadResponse command.params['parent'] = parent unless parent.nil? command.query['uri'] = uri unless uri.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#lookup_project_location_service_project_attachment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::LookupServiceProjectAttachmentResponse
Lists a service project attachment for a given service project. You can call this API from any project to find if it is attached to a host project.
191 192 193 194 195 196 197 198 199 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 191 def (name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}:lookupServiceProjectAttachment', ) command.response_representation = Google::Apis::ApphubV1alpha::LookupServiceProjectAttachmentResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::LookupServiceProjectAttachmentResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_application(name, application_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Updates an Application in a host project and location.
456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 456 def patch_project_location_application(name, application_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/{+name}', ) command.request_representation = Google::Apis::ApphubV1alpha::Application::Representation command.request_object = application_object command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_application_service(name, service_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Updates a Service in an Application.
760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 760 def patch_project_location_application_service(name, service_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/{+name}', ) command.request_representation = Google::Apis::ApphubV1alpha::Service::Representation command.request_object = service_object command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_application_workload(name, workload_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Operation
Updates a Workload in an Application.
989 990 991 992 993 994 995 996 997 998 999 1000 1001 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 989 def patch_project_location_application_workload(name, workload_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/{+name}', ) command.request_representation = Google::Apis::ApphubV1alpha::Workload::Representation command.request_object = workload_object command.response_representation = Google::Apis::ApphubV1alpha::Operation::Representation command.response_class = Google::Apis::ApphubV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_application_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
495 496 497 498 499 500 501 502 503 504 505 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 495 def set_application_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ApphubV1alpha::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::ApphubV1alpha::Policy::Representation command.response_class = Google::Apis::ApphubV1alpha::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_application_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1alpha::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
534 535 536 537 538 539 540 541 542 543 544 |
# File 'lib/google/apis/apphub_v1alpha/service.rb', line 534 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ApphubV1alpha::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ApphubV1alpha::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::ApphubV1alpha::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |