Class: Google::Apis::ApphubV1alpha::Service

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apphub_v1alpha/classes.rb,
lib/google/apis/apphub_v1alpha/representations.rb,
lib/google/apis/apphub_v1alpha/representations.rb

Overview

Service is an App Hub data model that contains a discovered service, which represents a network or API interface that exposes some functionality to clients for consumption over the network.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Service

Returns a new instance of Service.



1341
1342
1343
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1341

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesGoogle::Apis::ApphubV1alpha::Attributes

Consumer provided attributes. Corresponds to the JSON property attributes



1285
1286
1287
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1285

def attributes
  @attributes
end

#create_timeString

Output only. Create time. Corresponds to the JSON property createTime

Returns:

  • (String)


1290
1291
1292
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1290

def create_time
  @create_time
end

#descriptionString

Optional. User-defined description of a Service. Can have a maximum length of 2048 characters. Corresponds to the JSON property description

Returns:

  • (String)


1296
1297
1298
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1296

def description
  @description
end

#discovered_serviceString

Required. Immutable. The resource name of the original discovered service. Corresponds to the JSON property discoveredService

Returns:

  • (String)


1301
1302
1303
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1301

def discovered_service
  @discovered_service
end

#display_nameString

Optional. User-defined name for the Service. Can have a maximum length of 63 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


1307
1308
1309
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1307

def display_name
  @display_name
end

#nameString

Identifier. The resource name of a Service. Format: "projects/host-project- id/locations/location/applications/application-id/services/service-id" Corresponds to the JSON property name

Returns:

  • (String)


1313
1314
1315
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1313

def name
  @name
end

#service_propertiesGoogle::Apis::ApphubV1alpha::ServiceProperties

Properties of an underlying cloud resource that can comprise a Service. Corresponds to the JSON property serviceProperties



1318
1319
1320
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1318

def service_properties
  @service_properties
end

#service_referenceGoogle::Apis::ApphubV1alpha::ServiceReference

Reference to an underlying networking resource that can comprise a Service. Corresponds to the JSON property serviceReference



1323
1324
1325
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1323

def service_reference
  @service_reference
end

#stateString

Output only. Service state. Corresponds to the JSON property state

Returns:

  • (String)


1328
1329
1330
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1328

def state
  @state
end

#uidString

Output only. A universally unique identifier (UUID) for the Service in the UUID4 format. Corresponds to the JSON property uid

Returns:

  • (String)


1334
1335
1336
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1334

def uid
  @uid
end

#update_timeString

Output only. Update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


1339
1340
1341
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1339

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1346

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @discovered_service = args[:discovered_service] if args.key?(:discovered_service)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @service_properties = args[:service_properties] if args.key?(:service_properties)
  @service_reference = args[:service_reference] if args.key?(:service_reference)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end