Class: Google::Apis::ApphubV1alpha::ServiceProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apphub_v1alpha/classes.rb,
lib/google/apis/apphub_v1alpha/representations.rb,
lib/google/apis/apphub_v1alpha/representations.rb

Overview

Properties of an underlying cloud resource that can comprise a Service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceProperties

Returns a new instance of ServiceProperties.



1440
1441
1442
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1440

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#functional_typeGoogle::Apis::ApphubV1alpha::FunctionalType

The functional type of a service or workload. Corresponds to the JSON property functionalType



1420
1421
1422
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1420

def functional_type
  @functional_type
end

#gcp_projectString

Output only. The service project identifier that the underlying cloud resource resides in. Corresponds to the JSON property gcpProject

Returns:

  • (String)


1426
1427
1428
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1426

def gcp_project
  @gcp_project
end

#locationString

Output only. The location that the underlying resource resides in, for example, us-west1. Corresponds to the JSON property location

Returns:

  • (String)


1432
1433
1434
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1432

def location
  @location
end

#zoneString

Output only. The location that the underlying resource resides in if it is zonal, for example, us-west1-a). Corresponds to the JSON property zone

Returns:

  • (String)


1438
1439
1440
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1438

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1445
1446
1447
1448
1449
1450
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1445

def update!(**args)
  @functional_type = args[:functional_type] if args.key?(:functional_type)
  @gcp_project = args[:gcp_project] if args.key?(:gcp_project)
  @location = args[:location] if args.key?(:location)
  @zone = args[:zone] if args.key?(:zone)
end