Class: Google::Apis::ApphubV1alpha::Workload

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apphub_v1alpha/classes.rb,
lib/google/apis/apphub_v1alpha/representations.rb,
lib/google/apis/apphub_v1alpha/representations.rb

Overview

Workload is an App Hub data model that contains a discovered workload, which represents a binary deployment (such as managed instance groups (MIGs) and GKE deployments) that performs the smallest logical subset of business functionality.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Workload

Returns a new instance of Workload.



1680
1681
1682
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1680

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesGoogle::Apis::ApphubV1alpha::Attributes

Consumer provided attributes. Corresponds to the JSON property attributes



1623
1624
1625
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1623

def attributes
  @attributes
end

#create_timeString

Output only. Create time. Corresponds to the JSON property createTime

Returns:

  • (String)


1628
1629
1630
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1628

def create_time
  @create_time
end

#descriptionString

Optional. User-defined description of a Workload. Can have a maximum length of 2048 characters. Corresponds to the JSON property description

Returns:

  • (String)


1634
1635
1636
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1634

def description
  @description
end

#discovered_workloadString

Required. Immutable. The resource name of the original discovered workload. Corresponds to the JSON property discoveredWorkload

Returns:

  • (String)


1639
1640
1641
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1639

def discovered_workload
  @discovered_workload
end

#display_nameString

Optional. User-defined name for the Workload. Can have a maximum length of 63 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


1645
1646
1647
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1645

def display_name
  @display_name
end

#nameString

Identifier. The resource name of the Workload. Format: "projects/host- project-id/locations/location/applications/application-id/workloads/ workload-id" Corresponds to the JSON property name

Returns:

  • (String)


1652
1653
1654
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1652

def name
  @name
end

#stateString

Output only. Workload state. Corresponds to the JSON property state

Returns:

  • (String)


1657
1658
1659
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1657

def state
  @state
end

#uidString

Output only. A universally unique identifier (UUID) for the Workload in the UUID4 format. Corresponds to the JSON property uid

Returns:

  • (String)


1663
1664
1665
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1663

def uid
  @uid
end

#update_timeString

Output only. Update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


1668
1669
1670
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1668

def update_time
  @update_time
end

#workload_propertiesGoogle::Apis::ApphubV1alpha::WorkloadProperties

Properties of an underlying compute resource represented by the Workload. Corresponds to the JSON property workloadProperties



1673
1674
1675
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1673

def workload_properties
  @workload_properties
end

#workload_referenceGoogle::Apis::ApphubV1alpha::WorkloadReference

Reference of an underlying compute resource represented by the Workload. Corresponds to the JSON property workloadReference



1678
1679
1680
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1678

def workload_reference
  @workload_reference
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1685

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @discovered_workload = args[:discovered_workload] if args.key?(:discovered_workload)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @workload_properties = args[:workload_properties] if args.key?(:workload_properties)
  @workload_reference = args[:workload_reference] if args.key?(:workload_reference)
end