Class: Google::Apis::ApphubV1alpha::WorkloadProperties
- Inherits:
-
Object
- Object
- Google::Apis::ApphubV1alpha::WorkloadProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apphub_v1alpha/classes.rb,
lib/google/apis/apphub_v1alpha/representations.rb,
lib/google/apis/apphub_v1alpha/representations.rb
Overview
Properties of an underlying compute resource represented by the Workload.
Instance Attribute Summary collapse
-
#extended_metadata ⇒ Hash<String,Google::Apis::ApphubV1alpha::ExtendedMetadata>
Output only.
-
#functional_type ⇒ Google::Apis::ApphubV1alpha::FunctionalType
The functional type of a service or workload.
-
#gcp_project ⇒ String
Output only.
-
#identity ⇒ Google::Apis::ApphubV1alpha::Identity
The identity associated with a service or workload.
-
#location ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadProperties
constructor
A new instance of WorkloadProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadProperties
Returns a new instance of WorkloadProperties.
1926 1927 1928 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1926 def initialize(**args) update!(**args) end |
Instance Attribute Details
#extended_metadata ⇒ Hash<String,Google::Apis::ApphubV1alpha::ExtendedMetadata>
Output only. Additional metadata specific to the resource type. The key is a
string that identifies the type of metadata and the value is the metadata
contents specific to that type. Key format: apphub.googleapis.com/
metadataType`
Corresponds to the JSON propertyextendedMetadata`
1896 1897 1898 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1896 def @extended_metadata end |
#functional_type ⇒ Google::Apis::ApphubV1alpha::FunctionalType
The functional type of a service or workload.
Corresponds to the JSON property functionalType
1901 1902 1903 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1901 def functional_type @functional_type end |
#gcp_project ⇒ String
Output only. The service project identifier that the underlying cloud resource
resides in. Empty for non-cloud resources.
Corresponds to the JSON property gcpProject
1907 1908 1909 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1907 def gcp_project @gcp_project end |
#identity ⇒ Google::Apis::ApphubV1alpha::Identity
The identity associated with a service or workload.
Corresponds to the JSON property identity
1912 1913 1914 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1912 def identity @identity end |
#location ⇒ String
Output only. The location that the underlying compute resource resides in (for
example, us-west1).
Corresponds to the JSON property location
1918 1919 1920 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1918 def location @location end |
#zone ⇒ String
Output only. The location that the underlying compute resource resides in if
it is zonal (for example, us-west1-a).
Corresponds to the JSON property zone
1924 1925 1926 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1924 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1931 1932 1933 1934 1935 1936 1937 1938 |
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1931 def update!(**args) @extended_metadata = args[:extended_metadata] if args.key?(:extended_metadata) @functional_type = args[:functional_type] if args.key?(:functional_type) @gcp_project = args[:gcp_project] if args.key?(:gcp_project) @identity = args[:identity] if args.key?(:identity) @location = args[:location] if args.key?(:location) @zone = args[:zone] if args.key?(:zone) end |