Class: Google::Apis::ApphubV1alpha::WorkloadProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apphub_v1alpha/classes.rb,
lib/google/apis/apphub_v1alpha/representations.rb,
lib/google/apis/apphub_v1alpha/representations.rb

Overview

Properties of an underlying compute resource represented by the Workload.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadProperties

Returns a new instance of WorkloadProperties.



1727
1728
1729
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1727

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#functional_typeGoogle::Apis::ApphubV1alpha::FunctionalType

The functional type of a service or workload. Corresponds to the JSON property functionalType



1707
1708
1709
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1707

def functional_type
  @functional_type
end

#gcp_projectString

Output only. The service project identifier that the underlying cloud resource resides in. Empty for non-cloud resources. Corresponds to the JSON property gcpProject

Returns:

  • (String)


1713
1714
1715
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1713

def gcp_project
  @gcp_project
end

#locationString

Output only. The location that the underlying compute resource resides in (for example, us-west1). Corresponds to the JSON property location

Returns:

  • (String)


1719
1720
1721
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1719

def location
  @location
end

#zoneString

Output only. The location that the underlying compute resource resides in if it is zonal (for example, us-west1-a). Corresponds to the JSON property zone

Returns:

  • (String)


1725
1726
1727
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1725

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1732
1733
1734
1735
1736
1737
# File 'lib/google/apis/apphub_v1alpha/classes.rb', line 1732

def update!(**args)
  @functional_type = args[:functional_type] if args.key?(:functional_type)
  @gcp_project = args[:gcp_project] if args.key?(:gcp_project)
  @location = args[:location] if args.key?(:location)
  @zone = args[:zone] if args.key?(:zone)
end